powered by
This function automatically reshapes long (stacked) raw data from the API (get_data(..., wide = FALSE)) to a wide format where each variable has its own column.
get_data(..., wide = FALSE)
long2wide( data, id_cols = intersect(.Tvars, names(data)), names_from = "Series", values_from = "Value", labels_from = if (any(names(data) == "Label")) "Label" else NULL, expand.date = FALSE, ... )
A data.table with the reshaped data.
data.table
raw data from the API: A long format data frame where all values are stacked in a value column.
character. Temporal identifiers of the data. By default all variables in .Tvars are selected.
.Tvars
character. The column containing the series codes. These will become the names of the new columns in the wider data format.
character. The column containing the data values.
character. The column containing the labels describing the series.
logical. TRUE will call expand_date on the data after reshaping.
TRUE
expand_date
further arguments passed to dcast or expand_date, no conflicts between these two.
dcast
wide2long, wide2excel, ugatsdb
wide2long
wide2excel
ugatsdb
# \donttest{ # Return monthly macroeconomic indicators from the year 2000 onwards long2wide(get_data("BOU_MMI", from = 2000, wide = FALSE)) # }
Run the code above in your browser using DataLab