powered by
This function automatically reshapes wide (column-based) data into a long format akin to the format of the raw data coming from the database (get_data(..., wide = FALSE)).
get_data(..., wide = FALSE)
wide2long( data, id_cols = intersect(.Tvars, names(data)), to_value = setdiff(names(data), id_cols), variable_name = "Series", value_name = "Value", label_name = "Label", na.rm = TRUE, ... )
A data.table with the reshaped data.
data.table
a wide format data frame where all series have their own column.
character. Temporal identifiers of the data. By default all variables in .Tvars are selected.
.Tvars
character. The names of all series to be stacked into the long format data frame.
character. The name of the variable to store the names of the series.
character. The name of the variable to store the data values.
character. The name of the variable to store the series labels.
logical. TRUE will remove all missing values from the long data frame.
TRUE
further arguments passed to melt.
melt
long2wide, ugatsdb
long2wide
ugatsdb
# \donttest{ # Return monthly macroeconomic indicators from the year 2000 onwards data <- get_data("BOU_MMI", from = 2000) wide2long(data) # }
Run the code above in your browser using DataLab